pd_string_append

Function pd_string_append 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pd_string_append( a: *mut PdString, b: *const PdString, )
String append (modifies first string)

Safety

The caller must ensure that:

  • a is a valid mutable pointer to a PdString struct
  • b is a valid pointer to a PdString struct
  • The data fields in both structs point to valid null-terminated C strings
  • The caller is responsible for the memory management of the PdString at a