#[unsafe(no_mangle)]pub unsafe extern "C" fn pd_string_append(
a: *mut PdString,
b: *const PdString,
)Expand description
String append (modifies first string)
Safety
The caller must ensure that:
ais a valid mutable pointer to a PdString structbis a valid pointer to a PdString struct- The data fields in both structs point to valid null-terminated C strings
- The caller is responsible for the memory management of the PdString at
a